import React from 'react';
import { StyleSheet, Text, TouchableOpacity, View } from 'react-native';
import Icon from 'react-native-vector-icons/MaterialCommunityIcons';
import Search from 'react-native-vector-icons/MaterialIcons';
import { colors, constant } from '../constant';

const AppBar = ({
  label,
  appBarType,
  appBarColor,
  labelColor,
  iconColor,
  onBackPress,
  onCalenderPress,
  onMenuPress,
  onSearchPress,
  elevated,
}) => {
  const height =
    appBarType === constant.MEDIUM_HEADER
      ? 112
      : appBarType === constant.LARGE_HEADER
      ? 152
      : 64;

  const styles = StyleSheet.create({
    root: {
      backgroundColor: appBarColor ? appBarColor : colors.primary,
      elevation: elevated ? 5 : 0,
      height: height,
      justifyContent: 'space-evenly',
    },
    rowContainer: {
      flexDirection: 'row',
      justifyContent: 'space-between',
    },
    labelContainer: { flex: 1, marginHorizontal: 10 },
    centeredLabelContainer: {
      flex: 1,
      alignItems: 'center',
      marginHorizontal: 10,
    },
    bottomLabelContainer: { marginHorizontal: 10 },
    labelStyle: {
      color: labelColor ? labelColor : colors.primaryTextColor,
      fontSize: 20,
    },
    biglabelStyle: {
      color: labelColor ? labelColor : colors.primaryTextColor,
      fontSize: 24,
    },
    iconsContainer: { flexDirection: 'row' },
    pressable: {
      marginHorizontal: 5,
    },
  });

  return (
    <View style={styles.root}>
      <View style={styles.rowContainer}>
        {appBarType !== constant.CONTENT ? (
          <TouchableOpacity style={styles.pressable} onPress={onBackPress}>
            <Icon
              name="keyboard-backspace"
              size={30}
              color={iconColor ? iconColor : colors.primaryTextColor}
            />
          </TouchableOpacity>
        ) : null}

        {appBarType === constant.BACK_ACTION ||
        appBarType === constant.CONTENT ||
        appBarType === constant.SMALL_HEADER ? (
          <View style={styles.labelContainer}>
            <Text style={styles.labelStyle}>{label}</Text>
          </View>
        ) : appBarType === constant.CENTER_ALINGED_HEADER ? (
          <View style={styles.centeredLabelContainer}>
            <Text style={styles.labelStyle}>{label}</Text>
          </View>
        ) : null}
        {appBarType === constant.ACTION ||
        appBarType === constant.MEDIUM_HEADER ||
        appBarType === constant.SMALL_HEADER ||
        appBarType === constant.LARGE_HEADER ||
        appBarType === constant.CENTER_ALINGED_HEADER ? (
          <View style={styles.iconsContainer}>
            {appBarType === constant.MEDIUM_HEADER ||
            appBarType === constant.LARGE_HEADER ||
            appBarType === constant.ACTION ? (
              <TouchableOpacity
                style={styles.pressable}
                onPress={onCalenderPress}
              >
                <Icon
                  name="calendar-today"
                  size={30}
                  color={iconColor ? iconColor : colors.primaryTextColor}
                />
              </TouchableOpacity>
            ) : null}
            <TouchableOpacity style={styles.pressable} onPress={onSearchPress}>
              <Search
                name="search"
                size={30}
                color={iconColor ? iconColor : colors.primaryTextColor}
              />
            </TouchableOpacity>
            <TouchableOpacity style={styles.pressable} onPress={onMenuPress}>
              <Icon
                name="dots-vertical"
                size={30}
                color={iconColor ? iconColor : colors.primaryTextColor}
              />
            </TouchableOpacity>
          </View>
        ) : null}
      </View>
      {appBarType === constant.MEDIUM_HEADER ||
      appBarType === constant.LARGE_HEADER ? (
        <View style={styles.bottomLabelContainer}>
          {appBarType === constant.LARGE_HEADER ? (
            <Text style={styles.biglabelStyle}>{label}</Text>
          ) : (
            <Text style={styles.labelStyle}>{label}</Text>
          )}
        </View>
      ) : null}
    </View>
  );
};

export default AppBar;
